Package: m6Aboost
Type: Package
Title: m6Aboost
Version: 1.19.0
Date: 2025-06-27
Authors@R: c(person(given = "You",
                    family = "Zhou",
                    role = c("aut", "cre"),
                    email = "youzhoulearning@gmail.com",
                    comment = c(ORCID = "0000-0003-1755-9073")),
             person(given = "Kathi",
                    family = "Zarnack",
                    role = c("aut"),
                    email = "kathi.zarnack@bmls.de",
                    comment = c(ORCID = "0000-0003-3527-3378")))
Description: This package can help user to run the m6Aboost model on
        their own miCLIP2 data. The package includes functions to
        assign the read counts and get the features to run the m6Aboost
        model. The miCLIP2 data should be stored in a GRanges object.
        More details can be found in the vignette.
License: Artistic-2.0
VignetteBuilder: knitr
URL: https://github.com/ZarnackGroup/m6Aboost
BugReports: https://github.com/ZarnackGroup/m6Aboost/issues
biocViews: Sequencing, Epigenetics, Genetics, ExperimentHubSoftware
Encoding: UTF-8
RoxygenNote: 7.1.1
Imports: dplyr, rtracklayer, BSgenome, Biostrings, utils, methods,
        IRanges, ExperimentHub
Depends: S4Vectors, adabag, GenomicRanges, R (>= 4.1)
Suggests: knitr, rmarkdown, bookdown, testthat, BiocStyle,
        BSgenome.Mmusculus.UCSC.mm10
Config/pak/sysreqs: make libbz2-dev libicu-dev liblzma-dev libpng-dev
        libxml2-dev libssl-dev xz-utils zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:56:21 UTC
RemoteUrl: https://github.com/bioc/m6Aboost
RemoteRef: HEAD
RemoteSha: 63cb5e5f01d7d29efedc55dfc4dc5cf302e1b0aa
NeedsCompilation: no
Packaged: 2026-05-30 07:53:17 UTC; root
Author: You Zhou [aut, cre] (ORCID: <https://orcid.org/0000-0003-1755-9073>),
  Kathi Zarnack [aut] (ORCID: <https://orcid.org/0000-0003-3527-3378>)
Maintainer: You Zhou <youzhoulearning@gmail.com>
Built: R 4.6.0; ; 2026-05-30 11:26:07 UTC; unix
