# Generated by roxygen2: do not edit by hand

export(CtoTAssignment)
export(m6Aboost)
export(preparingData)
export(truncationAssignment)
import(ExperimentHub)
import(GenomicRanges)
import(IRanges, except = c(collapse, slice, desc))
import(adabag)
import(dplyr, except = c(union, intersect, setdiff))
import(methods)
importFrom(BSgenome,getBSgenome)
importFrom(Biostrings,getSeq)
importFrom(S4Vectors,elementMetadata)
importFrom(S4Vectors,mcols)
importFrom(rtracklayer,import.bw)
importFrom(rtracklayer,import.gff3)
importFrom(utils,globalVariables)
